/*
** Module   : WebClientBuilderParameters.java
** Abstract : store the web client process parameters
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- -------------------------------Description------------------------------------
** 001 CA  20140206 Created initial version, extracted from ClientBuilderParameters.
** 002 GES 20150312 Store the web client type.
*/

package com.goldencode.p2j.main;

import java.util.*;

/**
 * This structure holds default parameters as well specific parameters used to create and spawn a 
 * process for a web client (either GUI or ChUI). 
 */
public class WebClientBuilderParameters
extends ClientBuilderParameters
{   
   /** Referrer. */
   private String referrer;
   
   /** Flag that denotes client type (<code>true</code> for GUI, <code>false</code> for ChUI). */
   private boolean isGui;

   /**
    * Constructor. Assign a unique UUID to this process.
    *
    * @param    isGui
    *           Flag that denotes client type (<code>true</code> for GUI, <code>false</code> for
    *           ChUI).
    */
   public WebClientBuilderParameters(boolean isGui)
   {
      super(WebClientBuilderOptions.getInstance());
      this.isGui = isGui;
   }
   
   /**
    * Get Terminal Options.
    * 
    * @return  The terminal options.
    */
   public Map<String, String> getClientOptions()
   {
      return ((WebClientBuilderOptions) options).getClientOptions();
   }

   /**
    * Get referrer address.
    * 
    * @return  Back link URL
    */
   public String getReferrer()
   {
      return referrer;
   }

   /**
    * Set referrer address.
    * 
    * @param   referrer
    *          Back link URL
    */
   public void setReferrer(String referrer)
   {
      this.referrer = referrer;
   }
   
   /**
    * Get the flag that reports which web client type is in use.
    * 
    * @return   Client type (<code>true</code> for GUI, <code>false</code> for ChUI).
    */
   public boolean isGui()
   {
      return isGui;                  
   }                                 

   /**
    * Set the flag that reports which web client type is in use.
    * 
    * @param    isGui
    *           Client type (<code>true</code> for GUI, <code>false</code> for ChUI).
    */
   public void setGui(boolean isGui)
   {
      this.isGui = isGui;
   }
}
