/*
** Module   : TerminalOptions.java
** Abstract : configuration container
**
** Copyright (c) 2011-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 GES 20110921 Created initial version.
** 002 CA  20141029 Added flag to identify if the client must run in windows compatibility mode.
** 003 GES 20150424 Eliminated AWT dependency and moved to a generic location for better reuse.
*/

package com.goldencode.p2j.ui.client.chui.driver;

import com.goldencode.p2j.ui.*;

/**
 * Simple configuration container.
 */
public class TerminalOptions
{
   /** The default number of rows of text on the terminal screen. */
   public static int DEF_ROWS = 24;
   
   /** The default number of columns of text on the terminal screen. */
   public static int DEF_COLUMNS = 80;
   
   /** The default background color for each character (0x000000 - black). */
   public static ColorRgb DEF_BACKGROUND = new ColorRgb(0, 0, 0);
   
   /** The default foreground color for each character (0xFFA500 - amber). */
   public static ColorRgb DEF_FOREGROUND = new ColorRgb(255, 165, 0);
   
   /** The default color of the selection box (0x0000FF - blue). */
   public static ColorRgb DEF_SELECTION = new ColorRgb(0, 0, 255);
   
   /** The default font used for all text. */
   public static String DEF_FONTNAME = "monospaced";
   
   /** The default point size used for all text. */
   public static int DEF_FONTSIZE = 12;
   
   /** The number of rows of text on the terminal screen. */
   public int rows = DEF_ROWS;
   
   /** The number of columns of text on the terminal screen. */
   public int columns = DEF_COLUMNS;
   
   /** The background color for each character. */
   public ColorRgb background = DEF_BACKGROUND;
   
   /** The foreground color for each character. */
   public ColorRgb foreground = DEF_FOREGROUND;
   
   /** The color of the box when the user selects a rectangle of text. */
   public ColorRgb selection = DEF_SELECTION;
   
   /** The font used for all text. */
   public String fontname = DEF_FONTNAME;
   
   /** The font's point size used for all text. */
   public int fontsize = DEF_FONTSIZE;
   
   /** Flag indicating if the client is running in windows compatibility mode. */
   public boolean underWindows = false;
   
   /**
    * Compare the given instance to the current instance and report if the
    * two are equivalent. This implementation compares the data stored in
    * each instance member-wise.
    *
    * @param    options
    *           The instance with which the current data is compared.
    *
    * @return   <code>true</code> if both instances contain equivalent data.
    */
   public boolean equals(TerminalOptions options)
   {
      return (rows                == options.rows           &&
              columns             == options.columns        &&
              fontsize            == options.fontsize       &&
              underWindows        == options.underWindows   &&
              background.equals(options.background)         &&
              foreground.equals(options.foreground)         &&
              selection.equals(options.selection)           &&
              fontname.equalsIgnoreCase(options.fontname));
   }
}
