/*
** Module   : ChuiWebPageHandler.java
** Abstract : ChUI-specific page handler
**
** Copyright (c) 2013-2015 Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 MAG 20131105 Created initial version.
** 002 MAG 20140114 Add new replacements.
** 003 MAG 20140217 Add referrer replacement.
** 004 MAG 20140303 Add authorization token.
** 005 MAG 20140711 Enable/Disable clipboard.
** 006 MAG 20140723 Get authorization token as a query parameter and set a cookie for this domain
**                  if token match the expected value.
** 007 GES 20150312 Moved most code to a common class for shared usage.
*/

package com.goldencode.p2j.ui.client.chui.driver.web;

import org.eclipse.jetty.server.*;

import com.goldencode.p2j.cfg.*;
import com.goldencode.p2j.util.*;
import com.goldencode.p2j.web.*;
import com.goldencode.p2j.ui.client.driver.web.*;

/**
 * This code primarily exists to parse the HTML text and substitute place holders, but all the
 * rest of the handler functionality is in the parent class where it can be shared. 
 */
public class ChuiWebPageHandler
extends WebPageHandler
{
   /** Configuration. */
   private BootstrapConfig config;
   
   /**
    * Constructor.
    *
    * @param    config
    *           Configuration parameters.
    * @param    root
    *           Prefix for all URLs relating to this page.
    * @param    skel
    *           Fully qualified resource name of the HTML file which should be used.
    */
   public ChuiWebPageHandler(BootstrapConfig config, String root, String skel)
   {
      super(config, root, skel);
      this.config = config;
   }
   
   /**
    * Process the given string and make any replacements of parameter
    * values as needed. The replacement placeholder follow the JEE 
    * expression language (EL) format for immediate evaluation. 
    * <p>
    * Example: ${expression} 
    *
    * @param    base
    *           The details and state the request.
    * @param    text
    *           The text line that may need modifications.
    *
    * @return   The new text if a modification occurred or the original text
    *           if no modification was needed.
    */
   protected String handleReplacements(Request base, String text)
   {
      text = super.handleReplacements(base, text);
      
      if (text.contains("${client_title}"))
      {
         text = text.replace("${client_title}", "ChUI");
      }
      
      if (text.contains("${isGui}"))
      {
         text = text.replace("${isGui}", "false");
      }
      
      if (text.contains("${height_name}"))
      {
         text = text.replace("${height_name}", "rows");
      }                           
      
      if (text.contains("${height_val}"))
      {
         int rows = config.getInt("client", "chui", "rows", 24);
         text = text.replace("${height_val}", String.valueOf(rows));
      }                           
      
      if (text.contains("${width_name}"))
      {
         text = text.replace("${width_name}", "cols");
      }
      
      if (text.contains("${width_val}"))
      {
         int cols = config.getInt("client", "chui", "columns", 80);
         text = text.replace("${width_val}", String.valueOf(cols));
      }
      
      if (text.contains("${font.name}"))
      {
         String fontName = config.getString("client", "chui", "fontname", "monospace");
         text = text.replace("${font.name}", String.valueOf(fontName));
      }
      
      if (text.contains("${font.size}"))
      {
         int fontSize = config.getInt("client", "chui", "fontsize", 12);
         text = text.replace("${font.size}", String.valueOf(fontSize));
      }

      if (text.contains("${font.color}"))
      {
         String fontColor = config.getString("client", "chui", "foreground", "#FFA500");
         text = text.replace("${font.color}", htmlColor(fontColor));
      }

      if (text.contains("${font.background}"))
      {
         String fontBackground = config.getString("client", "chui", "background", "#000000");
         text = text.replace("${font.background}", htmlColor(fontBackground));
      }

      return text;
   }   
}
