/*
** Module   : GenericWebSocketCreator.java
** Abstract : custom generic WebSocketCreator implementation
**
** Copyright (c) 2013-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 MAG 20131112 Created initial version
** 002 GES 20150326 Javadoc cleanup and changed package to be web-specific.
*/

package com.goldencode.p2j.ui.client.driver.web;

import org.eclipse.jetty.websocket.servlet.*;

/**
 * A custom WebSocketCreator implementation which just returns the instance of the contained
 * object which implements web-sockets support.
 */
public class GenericWebSocketCreator<T> 
implements WebSocketCreator
{
   /** The chui WebSocket instance */
   private T webSocket;
   
   /**
    * Constructor.
    * 
    * @param   webSocket
    *          The <code>WebSocket</code> instance.
    */
   public GenericWebSocketCreator(T webSocket)
   {
      this.webSocket = webSocket;
   }

   /**
    * Obtain the WebSocket instance which is already created.
    *
    * @param   req
    *          WebSocket Upgrade request object.
    * @param   resp
    *          WebSocket Upgrade response object.
    *
    * @return  The contained instance which provides web-sockets support. 
    *
    */
   @Override
   public Object createWebSocket(ServletUpgradeRequest req, ServletUpgradeResponse resp)
   {
      return webSocket;
   }
}
